==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-test-utils/src/main/java/org/apache/streampipes/test/generator/EventPropertyPrimitiveTestBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.test.generator;

import org.apache.streampipes.model.schema.EventPropertyPrimitive;

import java.net.URI;
import java.util.List;

public class EventPropertyPrimitiveTestBuilder
    extends EventPropertyTestBuilder<EventPropertyPrimitive, EventPropertyPrimitiveTestBuilder> {

  protected EventPropertyPrimitiveTestBuilder() {
    super(new EventPropertyPrimitive());
  }

  public EventPropertyPrimitiveTestBuilder withSemanticType(String semanticType) {
    this.eventProperty.setDomainProperties(List.of(URI.create(semanticType)));
    return this;
  }

  public static EventPropertyPrimitiveTestBuilder create() {
    return new EventPropertyPrimitiveTestBuilder();
  }

  @Override
  public EventPropertyPrimitive build() {
    return eventProperty;
  }

  protected EventPropertyPrimitiveTestBuilder me() {
    return this;
  }
}

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-test-utils/src/main/java/org/apache/streampipes/test/generator/EventPropertyPrimitiveTestBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.test.generator;

import org.apache.streampipes.model.schema.EventPropertyPrimitive;
import org.apache.streampipes.model.schema.PropertyScope;

import java.net.URI;
import java.util.List;

public class EventPropertyPrimitiveTestBuilder
    extends EventPropertyTestBuilder<EventPropertyPrimitive, EventPropertyPrimitiveTestBuilder> {

  protected EventPropertyPrimitiveTestBuilder() {
    super(new EventPropertyPrimitive());
  }

  public EventPropertyPrimitiveTestBuilder withRuntimeType(URI runtimeType) {
    this.eventProperty.setRuntimeType(runtimeType.toString());
    return this;
  }

  public EventPropertyPrimitiveTestBuilder withPropertyScope(PropertyScope propertyScope) {
    this.eventProperty.setPropertyScope(propertyScope.toString());
    return this;
  }

  public EventPropertyPrimitiveTestBuilder withSemanticType(String semanticType) {
    this.eventProperty.setDomainProperties(List.of(URI.create(semanticType)));
    return this;
  }

  public static EventPropertyPrimitiveTestBuilder create() {
    return new EventPropertyPrimitiveTestBuilder();
  }

  @Override
  public EventPropertyPrimitive build() {
    return eventProperty;
  }

  protected EventPropertyPrimitiveTestBuilder me() {
    return this;
  }
}
